@@ -1,5 +1,5 @@
 #!/usr/bin/perl -w
-# Copyright (c) 2010-2017 Sullivan Beck.  All rights reserved.
+# Copyright (c) 2010-2018 Sullivan Beck.  All rights reserved.
 # This program is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 
@@ -504,6 +504,9 @@ $Data{'language'}{'iana'}{'orig'}{'name'} = {
    "ǀXam"                                          => "Xam",
    "ǁXegwi"                                        => "Xegwi",
    "Yan-nhaŋu Sign Language"                       => "Yan-nhanu Sign Language",
+   "Gaɓogbo"                                       => "Gabogbo",
+   "Guébie"                                        => "Guebie",
+   "Juǀʼhoansi"                                    => "Ju|'hoansi",
 };
 
 $Data{'language'}{'iana'}{'ignore'} = {
